pub enum PlanDecodeError {
TooLarge,
BadMagic,
Malformed,
UnsupportedSchema(u32),
LimitExceeded,
ResourceLimitExceeded,
IdentityMismatch,
InvalidBuffer,
InvalidPlan,
RealmMismatch,
UnknownToken,
UnauthorizedPlan,
}Variants
TooLarge
BadMagic
Malformed
UnsupportedSchema(u32)
LimitExceeded
ResourceLimitExceeded
IdentityMismatch
InvalidBuffer
InvalidPlan
RealmMismatch
UnknownToken
A vocabulary token this version assigns no meaning to. Before 0.3.0 the
derived enum bound produced Malformed for the same input.